@@ -492,20 +492,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
         }
     }
     '''
-    def create_or_replace_dataset(self, dataframe: pd.DataFrame, dataset_name: str, slug: str, icon_url=None,
-                                  settings: dict = None):
-        # Check if dataset exists
-        dataset_id = self.get_dataset_by_slug(self._slug, slug)
-
-        dataframe = dataframe.replace({np.nan: None})
-
-        if(dataset_id != None):
-            #If it exists update it
-            self.update_dataset(dataframe, dataset_name, slug, icon_url, settings)
-        else:
-            # If not exists create a new one
-            self.create_dataset(dataframe, dataset_name, slug, icon_url, settings)
-
 
     def delete_dataset(self, slug='', dataset_id=''):
 
